@@ -10,7 +10,7 @@ use parent 'RPi::WiringPi::Util';
 use RPi::WiringPi::Constant qw(:all);
 use RPi::WiringPi::Interrupt;
 
-our $VERSION = '2.36.6';
+our $VERSION = '2.36.7';
 
 sub new {
     my ($class, $pin) = @_;
@@ -115,7 +115,7 @@ RPi::WiringPi::Pin - Access and manipulate Raspberry Pi GPIO pins
 
     my $pin = RPi::WiringPi::Pin->new(5);
 
-    $pin->setup;
+    $pin->setup_gpio;
 
     $pin->mode(INPUT);
     $pin->write(LOW);
@@ -240,7 +240,7 @@ Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Steve Bertrand
+Copyright (C) 2017 by Steve Bertrand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
