@@ -7,7 +7,7 @@ use parent 'WiringPi::API';
 
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '2.36.6';
+our $VERSION = '2.36.7';
 
 sub gpio_layout {
     return $_[0]->gpio_layout;
@@ -230,9 +230,7 @@ C<1023>.
 
 Parameters:
 
-=over 8
-=item   $range
-=back
+    $range
 
 Mandatory: An integer specifying the high-end of the range. The range always
 starts at C<0>. Eg: if C<$range> is C<359>, if you incremented PWM by C<1>
@@ -292,7 +290,7 @@ Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Steve Bertrand
+Copyright (C) 2017 by Steve Bertrand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
